/*
 * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */
package com.openexchange.usm.database.ox.update;

import java.sql.Connection;
import java.sql.SQLException;
import com.openexchange.exception.OXException;
import com.openexchange.groupware.update.PerformParameters;
import com.openexchange.usm.api.database.StorageAccessException;
import com.openexchange.usm.api.exceptions.USMStorageException;
import com.openexchange.usm.database.ox.TableDefinition;
import com.openexchange.usm.database.ox.USMUpdateExceptionCodes;
import com.openexchange.usm.database.ox.USMUpdateTaskProvider;

public class USMTablesUpdateTaskV2 extends USMBaseUpdateTaskV2 {

	public USMTablesUpdateTaskV2(USMUpdateTaskProvider provider) {
		super(provider);
	}

	@Override
	protected void doPerform(PerformParameters params) throws OXException {
	    Connection con = params.getConnection();
        for (int i = 0; i < TableDefinition.TABLE_NAMES.length; i++) {
            createTable(TableDefinition.TABLE_NAMES[i], TableDefinition.SQL_STATEMENTS[i], con);
        }

        for (int i = 0; i < TableDefinition.SEQUENCE_TABLES_NAMES.length; i++) {
            try {
                String tablename = TableDefinition.SEQUENCE_TABLES_NAMES[i];
                TableDefinition.generateSequence(tablename, con, true, !tableExists(tablename,
                        con.getMetaData()));
            } catch (SQLException e) {
                throw USMUpdateExceptionCodes.SQL_ERROR.create(e);
            } catch (USMStorageException e) {
                throw USMUpdateExceptionCodes.SQL_ERROR.create(e);
            } catch (StorageAccessException e) {
                throw USMUpdateExceptionCodes.SQL_ERROR.create(e);
            }
        }
	}

	@Override
    public String[] getDependencies() {
		return new String[] { };
	}
}
